#!/bin/bash

usage() {
echo $"Usage: ./generator.sh [-n package-name] [-p launchpad-project]

Generates basic Apport hooks for a given package, so that its crash reports
go to its Launchpad project regardless of Ubuntu crash reporting.

Especially useful for PPA packages which don't have any crash reporting
facility provided by Ubuntu.

Options:
    -n <package>  Source package name for which the hook will be created
    -p <project>  Launchpad project name against which bugs will be filed
    -h            Display this help text

If either package name or Launchpad project is not provided on the command line,
the script will prompt the user to enter it.

The resulting files will be put in the current directory. On users' systems
*.conf files should be placed into /etc/apport/crashdb.conf.d/ and
*.py files to /usr/share/apport/package-hooks/" > /dev/stderr

}

# Parse command line options
while getopts "n:p:h\?" opt; do
    case "$opt" in
        n ) packagename="$OPTARG"                                       ;;
        p ) lp_project="$OPTARG"                                        ;;
        h ) usage; exit 0;                                              ;;
        \?) usage; exit 1;                                              ;;
        * ) echo $"Unknown option '$opt'" > /dev/stderr; usage; exit 1; ;;
    esac
done
shift $(($OPTIND -1))

if [ -z "$packagename" ]; then
    echo "Enter source package name:" > /dev/stderr
    read packagename
fi

if [ -z "$lp_project" ]; then
    echo "Enter Launchpad project, or hit enter if it's the same as package name:" > /dev/stderr
    read lp_project
    if [ -z "$lp_project" ]; then
       lp_project="$packagename"
    fi
fi

# this is needed for some Apport stuff, see https://wiki.ubuntu.com/Apport/DeveloperHowTo
package_name=$( echo "$packagename" | tr - _ )

echo "#!/usr/bin/python

'''Apport package hook for source package $packagename

(c) 2012 Robert Dyer, Rico Tzschichholz, Sergey \"Shnatsel\" Davidoff

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
'''

from apport.hookutils import *
from os import path
from subprocess import *

def add_info(report, ui=None):
	if not apport.packaging.is_distro_package(report['Package'].split()[0]):
		report['CrashDB'] = '$package_name'
	attach_gsettings_package (report, report['Package'].split()[0])
	try:
		gsettings_dump = check_output(['/usr/lib/apport-hooks-elementary/dump-gsettings-for-package', report['Package'].split()[0] ], stderr=STDOUT)
		if gsettings_dump != '':
			report['GSettings'] = gsettings_dump
	except CalledProcessError:
		report['GSettingsDumpFailed'] = 'GSettings-dumping command returned an error.\nThe output was:\n{0}\nPlease report a bug about it to the maintainer of your apport hooks.'.format(gsettings_dump)
	except OSError as e:
		report['GSettingsDumpFailed'] = 'Could not call GSettings-dumping command.\nThe error was: {0}\nPlease report a bug about it to the maintainer of your apport hooks.'.format(e.strerror)
	except ValueError as e:
		report['GSettingsDumpFailed'] = 'The function to invoke GSettings dump was called with invalid arguments.\nThe error was: {0}\nPlease report a bug about it to the maintainer of your apport hooks.'.format(e.strerror)" > 'source_'"$packagename"'.py'

echo "$package_name = {
	'impl' : 'launchpad',
	'project' : '"$lp_project"',
	'bug_pattern_base' : None,
	'initial_subscriber' : 'rabbitbot-a'
}" > "$packagename"-crashdb.conf

echo "Done. Please check if you need to attach any additional info and add that
to the scripts manually.

The generated files were placed in the CURRENT DIRECTORY.
On users' systems *.conf files should be placed into /etc/apport/crashdb.conf.d/
and *.py files to /usr/share/apport/package-hooks/
If you're running this script from elementary apport hooks branch, just move
both files to 'apport' folder in that branch and dpkg will install them for you."